@@ -1,31 +1,34 @@
 #' Get statistics of a Channel
 #'
 #' @param channel_id Character. Id of the channel
+#' @param mine Boolean. TRUE if you want to fetch stats of your own channel. Default is FALSE.
 #' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
-#' 
+#'
 #' @return nested named list with top element names:
 #' \code{kind, etag, id, snippet (list of details of the channel including title), statistics (list of 5)}
-#' 
+#'
 #' If the \code{channel_id} is mistyped or there is no information, an empty list is returned
-#' 
+#'
 #' @export
-#' 
+#'
 #' @references \url{https://developers.google.com/youtube/v3/docs/channels/list}
-#' 
+#'
 #' @examples
 #' \dontrun{
-#' 
+#'
 #' # Set API token via yt_oauth() first
-#' 
+#'
 #' get_channel_stats(channel_id="UCMtFAi84ehTSYSE9XoHefig")
 #' get_channel_stats(channel_id="UCMtFAi84ehTSYSE9Xo") # Incorrect channel ID
 #' }
 
-get_channel_stats <- function(channel_id = NULL, ...) {
+get_channel_stats <- function(channel_id = NULL, mine = FALSE, ...) {
 
-  if (!is.character(channel_id)) stop("Must specify a channel ID.")
+  if (!is.character(channel_id) & !identical(tolower(mine),  "true")) {
+          stop("Must specify a channel ID or specify mine = 'true'.")
+    }
 
-  querylist <- list(part = "statistics,snippet", id = channel_id)
+  querylist <- list(part = "statistics,snippet", id = channel_id, mine = mine)
 
   raw_res  <- tuber_GET("channels", querylist, ...)
 
